==> khttrack-0.10.tar.bz2: khttrack-0.10/khttrack/khttrackmirror.h <==
/***************************************************************************
                          khttrackmirror.h  -  description
                             -------------------
    begin                : Wed Jul 3 2002
    copyright            : (C) 2002 by Stphane Chapeau
    email                : nuscly@ifrance.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KHTTRACKMIRROR_H
#define KHTTRACKMIRROR_H

//#ifdef __cplusplus

#include <qwidget.h>
#include <mirrorview.h>

#include <qlabel.h>
#include <qgroupbox.h>
#include <qcheckbox.h>
#include <qframe.h>
#include <qmessagebox.h>

//#include "khttrack.h"

#include "khttrackstruct.h"
#include "khttrackmirrorc.h"


/**Widget d'affichage des sorties du moteur httrack
  *@author Stphane Chapeau
  */


class KhttrackMirror : public mirrorView  {
   Q_OBJECT
public: 
	KhttrackMirror(QWidget *parent=0, const char *name=0);
	~KhttrackMirror();
  /** Initilialise et lance le moteur */
  void launch();
  /** No descriptions */

  KhttrackStruct *project;
  char* Q1();
  char* Q2();
  char* Q3();
  /** Informe que le mirror est termin */
  void endMirror();



  
private:

//  KhttrackApp *khttrack ;

public slots:
//   void action_show();
   void action_show();
   void action_cancel();

};

  void *pth_showlog(void *threadid);

#endif

==> khttrack-0.11.tar.bz2: khttrack-0.11/khttrack/khttrackmirror.h <==
/***************************************************************************
                          khttrackmirror.h  -  description
                             -------------------
    begin                : Wed Jul 3 2002
    copyright            : (C) 2002 by Stphane Chapeau
    email                : nuscly-devel@laposte.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KHTTRACKMIRROR_H
#define KHTTRACKMIRROR_H

//#ifdef __cplusplus

#include <qwidget.h>
#include <mirrorview.h>

#include <qlabel.h>
#include <qgroupbox.h>
#include <qcheckbox.h>
#include <qframe.h>
#include <qmessagebox.h>

//#include "khttrack.h"

#include "khttrackstruct.h"
#include "khttrackmirrorc.h"


/**Widget d'affichage des sorties du moteur httrack
  *@author Stphane Chapeau
  */


class KhttrackMirror : public mirrorView  {
   Q_OBJECT
public: 
	KhttrackMirror(QWidget *parent=0, const char *name=0);
	~KhttrackMirror();
  /** Initilialise et lance le moteur */
  void launch();
  /** No descriptions */

  KhttrackStruct *project;
  char* Q1();
  char* Q2();
  char* Q3();
  /** Informe que le mirror est termin */
  void endMirror();



  
private:

//  KhttrackApp *khttrack ;

public slots:
//   void action_show();
   void action_show();
   void action_cancel();

};

  void *pth_showlog(void *threadid);

#endif
